SLIDER-187. Use start/stop instead of freeze/thaw

Project: http://git-wip-us.apache.org/repos/asf/incubator-slider/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-slider/commit/be548b87
Tree: http://git-wip-us.apache.org/repos/asf/incubator-slider/tree/be548b87
Diff: http://git-wip-us.apache.org/repos/asf/incubator-slider/diff/be548b87

Branch: refs/heads/feature/SLIDER-149_Support_a_YARN_service_registry
Commit: be548b8742324f2cde7ef48271ec3f19c53e8e5c
Parents: ffbc3a3
Author: Sumit Mohanty <smoha...@hortonworks.com>
Authored: Thu Aug 28 14:27:32 2014 -0700
Committer: Sumit Mohanty <smoha...@hortonworks.com>
Committed: Sat Aug 30 10:12:05 2014 -0700

----------------------------------------------------------------------
 README.md                                       |  4 +-
 slider-assembly/src/main/bash/README.md         |  2 +-
 slider-assembly/src/main/bash/slider_destroy    |  2 +-
 .../apache/slider/api/ClusterDescription.java   |  2 +-
 .../org/apache/slider/client/SliderClient.java  | 20 ++++-----
 .../common/SliderXMLConfKeysForTesting.java     |  8 ++--
 .../slider/common/params/ActionFreezeArgs.java  | 10 ++---
 .../slider/common/params/ActionThawArgs.java    |  6 +--
 .../apache/slider/common/params/ClientArgs.java |  4 +-
 .../common/params/LaunchArgsAccessor.java       |  2 +-
 .../slider/common/params/SliderActions.java     | 14 +++---
 .../server/appmaster/state/NodeEntry.java       |  2 +-
 .../server/appmaster/state/RoleHistory.java     | 14 +++---
 .../agent/actions/TestActionExists.groovy       |  2 +-
 .../agent/freezethaw/TestFreezeCommands.groovy  | 20 ++++-----
 .../TestFreezeThawMasterlessAM.groovy           |  8 ++--
 .../freezethaw/TestFreezeUnknownCluster.groovy  |  4 +-
 .../standalone/TestBuildStandaloneAM.groovy     |  8 ++--
 .../standalone/TestStandaloneAMDestroy.groovy   |  8 ++--
 .../standalone/TestStandaloneRegistryAM.groovy  |  2 +-
 .../slider/client/TestClientBadArgs.groovy      |  2 +-
 .../slider/client/TestCommonArgParsing.groovy   | 12 ++---
 .../model/history/TestRoleHistoryRW.groovy      |  2 +-
 .../slider/test/YarnMiniClusterTestBase.groovy  | 20 +++------
 .../src/test/resources/example-slider-test.xml  |  8 ++--
 .../framework/AgentCommandTestBase.groovy       |  2 +-
 .../funtest/framework/CommandTestBase.groovy    | 46 ++++++++++----------
 .../commands/UnknownClusterOperationsIT.groovy  |  9 ++--
 .../lifecycle/AgentClusterLifecycleIT.groovy    | 42 +++++++++---------
 .../src/test/manual/python/SliderTester.py      |  4 +-
 .../FunctionalAccumuloM1T1GC1Mon1IT.groovy      |  6 +--
 .../accumulo/live/TestAccFreezeThaw.groovy      |  2 +-
 .../funtest/HBaseClusterLifecycleIT.groovy      | 38 ++++++++--------
 .../TestFreezeThawClusterFromArchive.groovy     |  2 +-
 .../build/TestBuildThawClusterM1W1.groovy       | 10 ++---
 ...reezeReconfigureThawLiveRegionService.groovy | 12 ++---
 .../TestFreezeThawLiveRegionService.groovy      |  4 +-
 .../minicluster/live/TestTwoLiveClusters.groovy |  4 +-
 src/test/clusters/sandbox/operations.md         | 20 ++++-----
 src/test/clusters/ubuntu-secure/operations.md   | 14 +++---
 40 files changed, 197 insertions(+), 204 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/README.md
----------------------------------------------------------------------
diff --git a/README.md b/README.md
index b91e477..a25b83a 100644
--- a/README.md
+++ b/README.md
@@ -22,9 +22,9 @@ Slider is a YARN application to deploy existing distributed 
applications on YARN
 monitor them and make them larger or smaller as desired -even while 
 the cluster is running.
 
-Clusters can be stopped, "frozen" and restarted, "thawed" later; the 
distribution
+Clusters can be stopped and restarted later; the distribution
 of the deployed application across the YARN cluster is persisted -enabling
-a best-effort placement close to the previous locations on a cluster thaw.
+a best-effort placement close to the previous locations on a cluster start.
 Applications which remember the previous placement of data (such as HBase)
 can exhibit fast start-up times from this feature.
 

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-assembly/src/main/bash/README.md
----------------------------------------------------------------------
diff --git a/slider-assembly/src/main/bash/README.md 
b/slider-assembly/src/main/bash/README.md
index a4b7b08..d818aeb 100644
--- a/slider-assembly/src/main/bash/README.md
+++ b/slider-assembly/src/main/bash/README.md
@@ -79,7 +79,7 @@ Tear Down
 ---------
 
 * slider_destroy will do the following
-  1. Freeze the slider application based on provided name
+  1. Stop the slider application based on provided name
   2. Destory the slider application based on provided name
 
 * The following args are required

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-assembly/src/main/bash/slider_destroy
----------------------------------------------------------------------
diff --git a/slider-assembly/src/main/bash/slider_destroy 
b/slider-assembly/src/main/bash/slider_destroy
index 9039751..3b5ff53 100755
--- a/slider-assembly/src/main/bash/slider_destroy
+++ b/slider-assembly/src/main/bash/slider_destroy
@@ -54,7 +54,7 @@ source $config
 # Main
 #
 echo -e "\n## Freezing app $app_name"
-sudo -u yarn $SLIDER_INST_DIR/bin/slider freeze $app_name --manager 
$RM_ADDRESS || exit 1
+sudo -u yarn $SLIDER_INST_DIR/bin/slider stop $app_name --manager $RM_ADDRESS 
|| exit 1
 echo "SUCCESS"
 
 echo -e "\n## Destroying app $app_name"

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-core/src/main/java/org/apache/slider/api/ClusterDescription.java
----------------------------------------------------------------------
diff --git 
a/slider-core/src/main/java/org/apache/slider/api/ClusterDescription.java 
b/slider-core/src/main/java/org/apache/slider/api/ClusterDescription.java
index d875d66..9f4d83f 100644
--- a/slider-core/src/main/java/org/apache/slider/api/ClusterDescription.java
+++ b/slider-core/src/main/java/org/apache/slider/api/ClusterDescription.java
@@ -132,7 +132,7 @@ public class ClusterDescription implements Cloneable {
   
   /**
    * When was the cluster specification created?
-   * This is not the time a cluster was thawed; that will
+   * This is not the time a cluster was started; that will
    * be in the <code>info</code> section.
    */
   public long createTime;

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-core/src/main/java/org/apache/slider/client/SliderClient.java
----------------------------------------------------------------------
diff --git 
a/slider-core/src/main/java/org/apache/slider/common/SliderXMLConfKeysForTesting.java
 
b/slider-core/src/main/java/org/apache/slider/common/SliderXMLConfKeysForTesting.java
index 2cb6594..b845db2 100644
--- 
a/slider-core/src/main/java/org/apache/slider/common/SliderXMLConfKeysForTesting.java
+++ 
b/slider-core/src/main/java/org/apache/slider/common/SliderXMLConfKeysForTesting.java
@@ -30,14 +30,14 @@ public interface SliderXMLConfKeysForTesting {
   String KEY_TEST_ACCUMULO_TAR = "slider.test.accumulo.tar";
   String KEY_TEST_ACCUMULO_APPCONF = "slider.test.accumulo.appconf";
 
-  String KEY_TEST_THAW_WAIT_TIME = "slider.test.thaw.wait.seconds";
+  String KEY_TEST_START_WAIT_TIME = "slider.test.start.wait.seconds";
 
-  int DEFAULT_THAW_WAIT_TIME_SECONDS = 60;
+  int DEFAULT_START_WAIT_TIME_SECONDS = 60;
 
 
-  String KEY_TEST_FREEZE_WAIT_TIME = "slider.test.freeze.wait.seconds";
+  String KEY_TEST_STOP_WAIT_TIME = "slider.test.stop.wait.seconds";
 
-  int DEFAULT_TEST_FREEZE_WAIT_TIME_SECONDS = 60;
+  int DEFAULT_TEST_STOP_WAIT_TIME_SECONDS = 60;
 
   String KEY_TEST_TIMEOUT = "slider.test.timeout.seconds";
 

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-core/src/main/java/org/apache/slider/common/params/ActionFreezeArgs.java
----------------------------------------------------------------------
diff --git 
a/slider-core/src/main/java/org/apache/slider/common/params/ActionFreezeArgs.java
 
b/slider-core/src/main/java/org/apache/slider/common/params/ActionFreezeArgs.java
index 04f6305..328ddf5 100644
--- 
a/slider-core/src/main/java/org/apache/slider/common/params/ActionFreezeArgs.java
+++ 
b/slider-core/src/main/java/org/apache/slider/common/params/ActionFreezeArgs.java
@@ -22,17 +22,17 @@ import com.beust.jcommander.Parameter;
 import com.beust.jcommander.Parameters;
 import com.beust.jcommander.ParametersDelegate;
 
-@Parameters(commandNames = {SliderActions.ACTION_FREEZE},
-            commandDescription = SliderActions.DESCRIBE_ACTION_FREEZE)
+@Parameters(commandNames = {SliderActions.ACTION_STOP},
+            commandDescription = SliderActions.DESCRIBE_ACTION_STOP)
 
 public class ActionFreezeArgs extends AbstractActionArgs implements
                                                          WaitTimeAccessor {
   @Override
   public String getActionName() {
-    return SliderActions.ACTION_FREEZE;
+    return SliderActions.ACTION_STOP;
   }
   
-  public static final String FREEZE_COMMAND_ISSUED = "freeze command issued";
+  public static final String STOP_COMMAND_ISSUED = "stop command issued";
   @ParametersDelegate
   public WaitArgsDelegate waitDelegate = new WaitArgsDelegate();
 
@@ -48,7 +48,7 @@ public class ActionFreezeArgs extends AbstractActionArgs 
implements
 
   @Parameter(names={ARG_MESSAGE},
              description = "reason for the operation")
-  public String message = FREEZE_COMMAND_ISSUED;
+  public String message = STOP_COMMAND_ISSUED;
 
   @Parameter(names = {ARG_FORCE},
              description = "force the operation")

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-core/src/main/java/org/apache/slider/common/params/ActionThawArgs.java
----------------------------------------------------------------------
diff --git 
a/slider-core/src/main/java/org/apache/slider/common/params/ActionThawArgs.java 
b/slider-core/src/main/java/org/apache/slider/common/params/ActionThawArgs.java
index 8408385..9c8e961 100644
--- 
a/slider-core/src/main/java/org/apache/slider/common/params/ActionThawArgs.java
+++ 
b/slider-core/src/main/java/org/apache/slider/common/params/ActionThawArgs.java
@@ -21,8 +21,8 @@ package org.apache.slider.common.params;
 import com.beust.jcommander.Parameters;
 import com.beust.jcommander.ParametersDelegate;
 
-@Parameters(commandNames = {SliderActions.ACTION_THAW},
-            commandDescription = SliderActions.DESCRIBE_ACTION_THAW)
+@Parameters(commandNames = {SliderActions.ACTION_START},
+            commandDescription = SliderActions.DESCRIBE_ACTION_START)
 public class ActionThawArgs extends AbstractActionArgs implements
                                                        WaitTimeAccessor,
                                                        LaunchArgsAccessor {
@@ -30,7 +30,7 @@ public class ActionThawArgs extends AbstractActionArgs 
implements
 
   @Override
   public String getActionName() {
-    return SliderActions.ACTION_THAW;
+    return SliderActions.ACTION_START;
   }
 
   @Override

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-core/src/main/java/org/apache/slider/common/params/ClientArgs.java
----------------------------------------------------------------------
diff --git 
a/slider-core/src/main/java/org/apache/slider/common/params/ClientArgs.java 
b/slider-core/src/main/java/org/apache/slider/common/params/ClientArgs.java
index ca854f1..0c54739 100644
--- a/slider-core/src/main/java/org/apache/slider/common/params/ClientArgs.java
+++ b/slider-core/src/main/java/org/apache/slider/common/params/ClientArgs.java
@@ -192,10 +192,10 @@ public class ClientArgs extends CommonArgs {
     } else if (SliderActions.ACTION_UPDATE.equals(action)) {
       bindCoreAction(actionUpdateArgs);
 
-    } else if (SliderActions.ACTION_FREEZE.equals(action)) {
+    } else if (SliderActions.ACTION_STOP.equals(action)) {
       bindCoreAction(actionFreezeArgs);
 
-    } else if (SliderActions.ACTION_THAW.equals(action)) {
+    } else if (SliderActions.ACTION_START.equals(action)) {
       bindCoreAction(actionThawArgs);
 
     } else if (SliderActions.ACTION_AM_SUICIDE.equals(action)) {

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-core/src/main/java/org/apache/slider/common/params/LaunchArgsAccessor.java
----------------------------------------------------------------------
diff --git 
a/slider-core/src/main/java/org/apache/slider/common/params/LaunchArgsAccessor.java
 
b/slider-core/src/main/java/org/apache/slider/common/params/LaunchArgsAccessor.java
index f4ff4ce..c36a968 100644
--- 
a/slider-core/src/main/java/org/apache/slider/common/params/LaunchArgsAccessor.java
+++ 
b/slider-core/src/main/java/org/apache/slider/common/params/LaunchArgsAccessor.java
@@ -19,7 +19,7 @@
 package org.apache.slider.common.params;
 
 /**
- * Launch args for create and thaw and anything else that can start something
+ * Launch args for create and start and anything else that can start something
  */
 public interface LaunchArgsAccessor extends WaitTimeAccessor {
   String getRmAddress();

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-core/src/main/java/org/apache/slider/common/params/SliderActions.java
----------------------------------------------------------------------
diff --git 
a/slider-core/src/main/java/org/apache/slider/common/params/SliderActions.java 
b/slider-core/src/main/java/org/apache/slider/common/params/SliderActions.java
index 8e50a83..a295fa5 100644
--- 
a/slider-core/src/main/java/org/apache/slider/common/params/SliderActions.java
+++ 
b/slider-core/src/main/java/org/apache/slider/common/params/SliderActions.java
@@ -32,7 +32,7 @@ public interface SliderActions {
   String ACTION_ECHO = "echo";
   String ACTION_EXISTS = "exists";
   String ACTION_FLEX = "flex";
-  String ACTION_FREEZE = "freeze";
+  String ACTION_STOP = "stop";
   String ACTION_GETCONF = "getconf";
   String ACTION_HELP = "help";
   String ACTION_KILL_CONTAINER = "kill-container";
@@ -41,7 +41,7 @@ public interface SliderActions {
   String ACTION_RECONFIGURE = "reconfigure";
   String ACTION_REGISTRY = "registry";
   String ACTION_STATUS = "status";
-  String ACTION_THAW = "thaw";
+  String ACTION_START = "start";
   String ACTION_USAGE = "usage";
   String ACTION_VERSION = "version";
   String DESCRIBE_ACTION_AM_SUICIDE =
@@ -53,12 +53,12 @@ public interface SliderActions {
   String DESCRIBE_ACTION_UPDATE =
       "Update template for a Slider application";
   String DESCRIBE_ACTION_DESTROY =
-        "Destroy a frozen Slider application)";
+        "Destroy a stopped Slider application)";
   String DESCRIBE_ACTION_EXISTS =
             "Probe for an application running";
   String DESCRIBE_ACTION_FLEX = "Flex a Slider application";
-  String DESCRIBE_ACTION_FREEZE =
-              "Freeze/suspend a running application";
+  String DESCRIBE_ACTION_STOP =
+              "Stop a running application";
   String DESCRIBE_ACTION_GETCONF =
                 "Get the configuration of an application";
   String DESCRIBE_ACTION_KILL_CONTAINER =
@@ -72,8 +72,8 @@ public interface SliderActions {
                       "Query the registry of a YARN application";
   String DESCRIBE_ACTION_STATUS =
                       "Get the status of an application";
-  String DESCRIBE_ACTION_THAW =
-                        "Thaw a frozen application";
+  String DESCRIBE_ACTION_START =
+                        "Start a stopped application";
   String DESCRIBE_ACTION_VERSION =
                         "Print the Slider version information";
 }

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-core/src/main/java/org/apache/slider/server/appmaster/state/NodeEntry.java
----------------------------------------------------------------------
diff --git 
a/slider-core/src/main/java/org/apache/slider/server/appmaster/state/NodeEntry.java
 
b/slider-core/src/main/java/org/apache/slider/server/appmaster/state/NodeEntry.java
index c8ab2a7..83c590b 100644
--- 
a/slider-core/src/main/java/org/apache/slider/server/appmaster/state/NodeEntry.java
+++ 
b/slider-core/src/main/java/org/apache/slider/server/appmaster/state/NodeEntry.java
@@ -23,7 +23,7 @@ package org.apache.slider.server.appmaster.state;
  * No fields are synchronized; sync on the instance to work with it
  *
  The two fields `releasing` and `requested` are used to track the ongoing
- state of YARN requests; they do not need to be persisted across freeze/thaw
+ state of YARN requests; they do not need to be persisted across stop/start
  cycles. They may be relevant across AM restart, but without other data
  structures in the AM, not enough to track what the AM was up to before
  it was restarted. The strategy will be to ignore unexpected allocation

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-core/src/main/java/org/apache/slider/server/appmaster/state/RoleHistory.java
----------------------------------------------------------------------
diff --git 
a/slider-core/src/main/java/org/apache/slider/server/appmaster/state/RoleHistory.java
 
b/slider-core/src/main/java/org/apache/slider/server/appmaster/state/RoleHistory.java
index edcf7ea..c8971b7 100644
--- 
a/slider-core/src/main/java/org/apache/slider/server/appmaster/state/RoleHistory.java
+++ 
b/slider-core/src/main/java/org/apache/slider/server/appmaster/state/RoleHistory.java
@@ -334,7 +334,7 @@ public class RoleHistory {
    * Start up
    * @param fs filesystem 
    * @param historyDir path in FS for history
-   * @return true if the history was thawed
+   * @return true if the history was started
    */
   public boolean onStart(FileSystem fs, Path historyDir) throws
                                                          BadConfigException {
@@ -342,8 +342,8 @@ public class RoleHistory {
     filesystem = fs;
     historyPath = historyDir;
     startTime = now();
-    //assume the history is being thawed; this will downgrade as appropriate
-    return onThaw();
+    //assume the history is being started; this will downgrade as appropriate
+    return onSart();
     }
   
   /**
@@ -354,11 +354,11 @@ public class RoleHistory {
   }
 
   /**
-   * Handle the thaw process <i>after the history has been rebuilt</i>,
+   * Handle the start process <i>after the history has been rebuilt</i>,
    * and after any gc/purge
    */
   @VisibleForTesting
-  public synchronized boolean onThaw() throws BadConfigException {
+  public synchronized boolean onSart() throws BadConfigException {
     assert filesystem != null;
     assert historyPath != null;
     boolean thawSuccessful = false;
@@ -381,7 +381,7 @@ public class RoleHistory {
                  e);
       }
 
-      //thaw is then completed
+      //start is then completed
       buildAvailableNodeLists();
     } else {
       //fallback to bootstrap procedure
@@ -392,7 +392,7 @@ public class RoleHistory {
 
 
   /**
-   * (After the thaw), rebuild the availability datastructures
+   * (After the start), rebuild the availability data structures
    */
   @VisibleForTesting
   public synchronized void buildAvailableNodeLists() {

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-core/src/test/groovy/org/apache/slider/agent/actions/TestActionExists.groovy
----------------------------------------------------------------------
diff --git 
a/slider-core/src/test/groovy/org/apache/slider/agent/actions/TestActionExists.groovy
 
b/slider-core/src/test/groovy/org/apache/slider/agent/actions/TestActionExists.groovy
index 9bfeb8c..a190b7d 100644
--- 
a/slider-core/src/test/groovy/org/apache/slider/agent/actions/TestActionExists.groovy
+++ 
b/slider-core/src/test/groovy/org/apache/slider/agent/actions/TestActionExists.groovy
@@ -110,7 +110,7 @@ class TestActionExists extends AgentMiniClusterTestBase {
 
     assert 0 == sliderClient.actionExists(clustername, true)
     
-    // freeze the cluster
+    // stop the cluster
     clusterActionFreeze(sliderClient, clustername)
 
     //verify that exists(live) is now false

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-core/src/test/groovy/org/apache/slider/agent/freezethaw/TestFreezeCommands.groovy
----------------------------------------------------------------------
diff --git 
a/slider-core/src/test/groovy/org/apache/slider/agent/freezethaw/TestFreezeCommands.groovy
 
b/slider-core/src/test/groovy/org/apache/slider/agent/freezethaw/TestFreezeCommands.groovy
index f5eff25..bc6f620 100644
--- 
a/slider-core/src/test/groovy/org/apache/slider/agent/freezethaw/TestFreezeCommands.groovy
+++ 
b/slider-core/src/test/groovy/org/apache/slider/agent/freezethaw/TestFreezeCommands.groovy
@@ -45,7 +45,7 @@ class TestFreezeCommands extends AgentMiniClusterTestBase {
     YarnConfiguration conf = configuration
     String clustername = createMiniCluster("", conf, 1, 1, 1, true, false)
 
-    describe "create a masterless AM, freeze it, try to freeze again"
+    describe "create a masterless AM, stop it, try to stop again"
 
     ServiceLauncher<SliderClient> launcher = createStandaloneAM(
         clustername
@@ -59,19 +59,19 @@ class TestFreezeCommands extends AgentMiniClusterTestBase {
     assertSucceeded(execSliderCommand(conf,
         [SliderActions.ACTION_LIST, clustername]))
 
-    log.info("First Freeze command");
+    log.info("First Stop command");
     ServiceLauncher freezeCommand = execSliderCommand(conf,
         [
-            SliderActions.ACTION_FREEZE, clustername,
+            SliderActions.ACTION_STOP, clustername,
             Arguments.ARG_WAIT, waitTimeArg
         ]);
     assertSucceeded(freezeCommand)
 
-    log.info("Second Freeze command");
+    log.info("Second Stop command");
 
     ServiceLauncher<SliderClient> freeze2 = execSliderCommand(conf,
         [
-            SliderActions.ACTION_FREEZE, clustername,
+            SliderActions.ACTION_STOP, clustername,
             Arguments.ARG_WAIT, waitTimeArg
         ]);
     assertSucceeded(freeze2)
@@ -94,11 +94,11 @@ class TestFreezeCommands extends AgentMiniClusterTestBase {
       assert e.exitCode == LauncherExitCodes.EXIT_FALSE;
     }
 
-    log.info("First Thaw");
+    log.info("First Start");
 
 
     def commands = [
-        SliderActions.ACTION_THAW, clustername,
+        SliderActions.ACTION_START, clustername,
         Arguments.ARG_WAIT, waitTimeArg,
         Arguments.ARG_FILESYSTEM, fsDefaultName
     ]
@@ -111,11 +111,11 @@ class TestFreezeCommands extends AgentMiniClusterTestBase 
{
     assertSucceeded(execSliderCommand(conf,
         [SliderActions.ACTION_EXISTS, clustername]))
 
-    log.info("Freeze 3");
+    log.info("Stop 3");
 
     ServiceLauncher<SliderClient> freeze3 = execSliderCommand(conf,
         [
-            SliderActions.ACTION_FREEZE, clustername,
+            SliderActions.ACTION_STOP, clustername,
             Arguments.ARG_WAIT, waitTimeArg
         ]);
     assertSucceeded(freeze3)
@@ -157,7 +157,7 @@ class TestFreezeCommands extends AgentMiniClusterTestBase {
 
     ServiceLauncher<SliderClient> freeze4 = execSliderCommand(conf,
         [
-            SliderActions.ACTION_FREEZE, clustername,
+            SliderActions.ACTION_STOP, clustername,
             Arguments.ARG_FORCE,
             Arguments.ARG_WAIT, waitTimeArg,
         ]);

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-core/src/test/groovy/org/apache/slider/agent/freezethaw/TestFreezeThawMasterlessAM.groovy
----------------------------------------------------------------------
diff --git 
a/slider-core/src/test/groovy/org/apache/slider/agent/freezethaw/TestFreezeThawMasterlessAM.groovy
 
b/slider-core/src/test/groovy/org/apache/slider/agent/freezethaw/TestFreezeThawMasterlessAM.groovy
index 04be7c0..5a1acef 100644
--- 
a/slider-core/src/test/groovy/org/apache/slider/agent/freezethaw/TestFreezeThawMasterlessAM.groovy
+++ 
b/slider-core/src/test/groovy/org/apache/slider/agent/freezethaw/TestFreezeThawMasterlessAM.groovy
@@ -31,7 +31,7 @@ import org.apache.slider.core.main.ServiceLauncher
 import org.junit.Test
 
 /**
- * freeze and thaw an AM
+ * stop and start an AM
  */
 @CompileStatic
 @Slf4j
@@ -52,7 +52,7 @@ class TestFreezeThawMasterlessAM extends 
AgentMiniClusterTestBase {
     YarnConfiguration conf = configuration
     String clustername = createMiniCluster("", conf, 1, 1, 1, true, false)
     
-    describe "create a masterless AM, freeze it, thaw it"
+    describe "create a masterless AM, stop it, start it"
     //copy the confdir somewhere
     Path resConfPath = new Path(resourceConfDirURI)
     Path tempConfPath = new Path(confDir)
@@ -81,10 +81,10 @@ class TestFreezeThawMasterlessAM extends 
AgentMiniClusterTestBase {
 
 //    ApplicationReport report = waitForClusterLive(newCluster)
     newCluster.getClusterDescription(clustername);
-    //freeze
+    //stop
     assert 0 == clusterActionFreeze(sliderClient, clustername)
 
-    //freeze again
+    //stop again
     assert 0 == clusterActionFreeze(sliderClient, clustername)
 
   }

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-core/src/test/groovy/org/apache/slider/agent/freezethaw/TestFreezeUnknownCluster.groovy
----------------------------------------------------------------------
diff --git 
a/slider-core/src/test/groovy/org/apache/slider/agent/freezethaw/TestFreezeUnknownCluster.groovy
 
b/slider-core/src/test/groovy/org/apache/slider/agent/freezethaw/TestFreezeUnknownCluster.groovy
index b81bc77..de31aac 100644
--- 
a/slider-core/src/test/groovy/org/apache/slider/agent/freezethaw/TestFreezeUnknownCluster.groovy
+++ 
b/slider-core/src/test/groovy/org/apache/slider/agent/freezethaw/TestFreezeUnknownCluster.groovy
@@ -42,12 +42,12 @@ class TestFreezeUnknownCluster extends 
AgentMiniClusterTestBase {
     YarnConfiguration conf = configuration
     String clustername = createMiniCluster("", conf, 1, true)
 
-    describe "try to freeze a cluster that isn't defined"
+    describe "try to stop a cluster that isn't defined"
 
     try {
       ServiceLauncher<SliderClient>  command = execSliderCommand(conf,
                                                 [
-                                                    
SliderActions.ACTION_FREEZE,
+                                                    SliderActions.ACTION_STOP,
                                                     "no-such-cluster"
                                                 ]);
       fail("Expected an error, got an exit code of ${command.serviceExitCode}")

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-core/src/test/groovy/org/apache/slider/agent/standalone/TestBuildStandaloneAM.groovy
----------------------------------------------------------------------
diff --git 
a/slider-core/src/test/groovy/org/apache/slider/agent/standalone/TestBuildStandaloneAM.groovy
 
b/slider-core/src/test/groovy/org/apache/slider/agent/standalone/TestBuildStandaloneAM.groovy
index 0665a9a..7e67d67 100644
--- 
a/slider-core/src/test/groovy/org/apache/slider/agent/standalone/TestBuildStandaloneAM.groovy
+++ 
b/slider-core/src/test/groovy/org/apache/slider/agent/standalone/TestBuildStandaloneAM.groovy
@@ -96,11 +96,11 @@ class TestBuildStandaloneAM extends 
AgentMiniClusterTestBase {
 
     
     
-    //thaw time
+    //start time
     ServiceLauncher<SliderClient> l2 = thawCluster(clustername, [], true)
-    SliderClient thawed = l2.service
-    addToTeardown(thawed);
-    waitForClusterLive(thawed)
+    SliderClient started = l2.service
+    addToTeardown(started);
+    waitForClusterLive(started)
   }
 
   @Test

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-core/src/test/groovy/org/apache/slider/agent/standalone/TestStandaloneAMDestroy.groovy
----------------------------------------------------------------------
diff --git 
a/slider-core/src/test/groovy/org/apache/slider/agent/standalone/TestStandaloneAMDestroy.groovy
 
b/slider-core/src/test/groovy/org/apache/slider/agent/standalone/TestStandaloneAMDestroy.groovy
index 17e4ff2..8847f7b 100644
--- 
a/slider-core/src/test/groovy/org/apache/slider/agent/standalone/TestStandaloneAMDestroy.groovy
+++ 
b/slider-core/src/test/groovy/org/apache/slider/agent/standalone/TestStandaloneAMDestroy.groovy
@@ -102,20 +102,20 @@ class TestStandaloneAMDestroy extends 
AgentMiniClusterTestBase {
     describe "post destroy checks"
     sliderFileSystem.verifyDirectoryNonexistent(instanceDir)
 
-    describe "thaw expected to fail"
-    //expect thaw to now fail
+    describe "start expected to fail"
+    //expect start to now fail
     def ex = launchExpectingException(SliderClient,
         configuration,
         "",
         [
-            SliderActions.ACTION_THAW,
+            SliderActions.ACTION_START,
             clustername,
             Arguments.ARG_FILESYSTEM, fsDefaultName,
             Arguments.ARG_MANAGER, RMAddr,
         ])
     assert ex instanceof UnknownApplicationInstanceException
 
-    describe "thaw completed, checking dir is still absent"
+    describe "start completed, checking dir is still absent"
     sliderFileSystem.verifyDirectoryNonexistent(instanceDir)
 
 

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-core/src/test/groovy/org/apache/slider/agent/standalone/TestStandaloneRegistryAM.groovy
----------------------------------------------------------------------
diff --git 
a/slider-core/src/test/groovy/org/apache/slider/agent/standalone/TestStandaloneRegistryAM.groovy
 
b/slider-core/src/test/groovy/org/apache/slider/agent/standalone/TestStandaloneRegistryAM.groovy
index b8a590e..cbbd030 100644
--- 
a/slider-core/src/test/groovy/org/apache/slider/agent/standalone/TestStandaloneRegistryAM.groovy
+++ 
b/slider-core/src/test/groovy/org/apache/slider/agent/standalone/TestStandaloneRegistryAM.groovy
@@ -342,7 +342,7 @@ class TestStandaloneRegistryAM extends 
AgentMiniClusterTestBase {
     registryArgs.getConf = unknownFilename
     assert SliderExitCodes.EXIT_NOT_FOUND == 
client.actionRegistry(registryArgs)
 
-    describe "freeze cluster"
+    describe "stop cluster"
     //now kill that cluster
     assert 0 == clusterActionFreeze(client, clustername)
     //list it & See if it is still there

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-core/src/test/groovy/org/apache/slider/client/TestClientBadArgs.groovy
----------------------------------------------------------------------
diff --git 
a/slider-core/src/test/groovy/org/apache/slider/client/TestClientBadArgs.groovy 
b/slider-core/src/test/groovy/org/apache/slider/client/TestClientBadArgs.groovy
index 088fdb3..5fe0c9d 100644
--- 
a/slider-core/src/test/groovy/org/apache/slider/client/TestClientBadArgs.groovy
+++ 
b/slider-core/src/test/groovy/org/apache/slider/client/TestClientBadArgs.groovy
@@ -53,7 +53,7 @@ class TestClientBadArgs extends ServiceLauncherBaseTest {
     launchExpectingException(SliderClient,
                              new Configuration(),
                              ErrorStrings.ERROR_NOT_ENOUGH_ARGUMENTS,
-                             [SliderActions.ACTION_THAW])
+                             [SliderActions.ACTION_START])
   }
 
   @Test

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-core/src/test/groovy/org/apache/slider/client/TestCommonArgParsing.groovy
----------------------------------------------------------------------
diff --git 
a/slider-core/src/test/groovy/org/apache/slider/client/TestCommonArgParsing.groovy
 
b/slider-core/src/test/groovy/org/apache/slider/client/TestCommonArgParsing.groovy
index d94cd54..1706678 100644
--- 
a/slider-core/src/test/groovy/org/apache/slider/client/TestCommonArgParsing.groovy
+++ 
b/slider-core/src/test/groovy/org/apache/slider/client/TestCommonArgParsing.groovy
@@ -154,13 +154,13 @@ class TestCommonArgParsing implements SliderActions, 
Arguments {
   }
 
   /**
-   * Test a thaw command
+   * Test a start command
    * @throws Throwable
    */
   @Test
   public void testComplexThaw() throws Throwable {
     ClientArgs ca = createClientArgs([
-        ACTION_THAW,
+        ACTION_START,
         "--manager", "rhel:8032", "--filesystem", "hdfs://rhel:9090",
         "-S","java.security.krb5.realm=LOCAL","-S", 
"java.security.krb5.kdc=rhel",
         "-D","yarn.resourcemanager.principal=yarn/rhel@LOCAL",
@@ -197,14 +197,14 @@ class TestCommonArgParsing implements SliderActions, 
Arguments {
   @Test
   public void testFreezeFailsNoArg() throws Throwable {
     assertParseFails([
-        ACTION_FREEZE,
+        ACTION_STOP,
     ])
   }
   
   @Test
   public void testFreezeWorks1Arg() throws Throwable {
     ClientArgs ca = createClientArgs([
-        ACTION_FREEZE,
+        ACTION_STOP,
         CLUSTERNAME,
     ])
     assert ca.clusterName == CLUSTERNAME
@@ -214,14 +214,14 @@ class TestCommonArgParsing implements SliderActions, 
Arguments {
   @Test
   public void testFreezeFails2Arg() throws Throwable {
     assertParseFails([
-        ACTION_FREEZE, "cluster", "cluster2"
+        ACTION_STOP, "cluster", "cluster2"
     ])
   }
 
   @Test
   public void testFreezeForceWaitAndMessage() throws Throwable {
     ClientArgs ca = createClientArgs([
-        ACTION_FREEZE, CLUSTERNAME,
+        ACTION_STOP, CLUSTERNAME,
         ARG_FORCE,
         ARG_WAIT, "0",
         ARG_MESSAGE, "explanation"

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-core/src/test/groovy/org/apache/slider/server/appmaster/model/history/TestRoleHistoryRW.groovy
----------------------------------------------------------------------
diff --git 
a/slider-core/src/test/groovy/org/apache/slider/server/appmaster/model/history/TestRoleHistoryRW.groovy
 
b/slider-core/src/test/groovy/org/apache/slider/server/appmaster/model/history/TestRoleHistoryRW.groovy
index 4242ba1..330c8f3 100644
--- 
a/slider-core/src/test/groovy/org/apache/slider/server/appmaster/model/history/TestRoleHistoryRW.groovy
+++ 
b/slider-core/src/test/groovy/org/apache/slider/server/appmaster/model/history/TestRoleHistoryRW.groovy
@@ -117,7 +117,7 @@ class TestRoleHistoryRW extends BaseMockAppStateTest {
     assert loadedNE2.lastUsed == savetime
     assert rh2.thawedDataTime == savetime
 
-    // now thaw it
+    // now start it
     rh2.buildAvailableNodeLists();
     describe("thawing")
     rh2.dump();

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-core/src/test/groovy/org/apache/slider/test/YarnMiniClusterTestBase.groovy
----------------------------------------------------------------------
diff --git 
a/slider-core/src/test/groovy/org/apache/slider/test/YarnMiniClusterTestBase.groovy
 
b/slider-core/src/test/groovy/org/apache/slider/test/YarnMiniClusterTestBase.groovy
index 5aef585..daba687 100644
--- 
a/slider-core/src/test/groovy/org/apache/slider/test/YarnMiniClusterTestBase.groovy
+++ 
b/slider-core/src/test/groovy/org/apache/slider/test/YarnMiniClusterTestBase.groovy
@@ -18,7 +18,6 @@
 
 package org.apache.slider.test
 
-import groovy.transform.CompileStatic
 import groovy.util.logging.Slf4j
 import org.apache.commons.logging.Log
 import org.apache.commons.logging.LogFactory
@@ -49,16 +48,11 @@ import org.apache.slider.core.main.ServiceLauncher
 import org.apache.slider.core.main.ServiceLauncherBaseTest
 import org.apache.slider.server.appmaster.SliderAppMaster
 import org.junit.After
-import org.junit.Assert
-import org.junit.Before
 import org.junit.BeforeClass
 import org.junit.Rule
-import org.junit.rules.TestName
 import org.junit.rules.Timeout
 
 import static org.apache.slider.test.KeysForTests.*
-
-import static org.apache.slider.common.SliderKeys.*;
 import static org.apache.slider.common.SliderXMLConfKeysForTesting.*;
 /**
  * Base class for mini cluster tests -creates a field for the
@@ -97,8 +91,8 @@ public abstract class YarnMiniClusterTestBase extends 
ServiceLauncherBaseTest {
   }
 
 
-  public int thawWaitTime = DEFAULT_THAW_WAIT_TIME_SECONDS * 1000
-  public int freezeWaitTime = DEFAULT_TEST_FREEZE_WAIT_TIME_SECONDS * 1000
+  public int thawWaitTime = DEFAULT_START_WAIT_TIME_SECONDS * 1000
+  public int freezeWaitTime = DEFAULT_TEST_STOP_WAIT_TIME_SECONDS * 1000
   public int sliderTestTimeout = DEFAULT_TEST_TIMEOUT_SECONDS * 1000
   public boolean teardownKillall = DEFAULT_TEARDOWN_KILLALL
   
@@ -164,10 +158,10 @@ public abstract class YarnMiniClusterTestBase extends 
ServiceLauncherBaseTest {
     super.setup()
     def testConf = testConfiguration;
     thawWaitTime = getTimeOptionMillis(testConf,
-        KEY_TEST_THAW_WAIT_TIME,
+        KEY_TEST_START_WAIT_TIME,
         thawWaitTime)
     freezeWaitTime = getTimeOptionMillis(testConf,
-        KEY_TEST_FREEZE_WAIT_TIME,
+        KEY_TEST_STOP_WAIT_TIME,
         freezeWaitTime)
     sliderTestTimeout = getTimeOptionMillis(testConf,
         KEY_TEST_TIMEOUT,
@@ -602,7 +596,7 @@ public abstract class YarnMiniClusterTestBase extends 
ServiceLauncherBaseTest {
     assert miniCluster != null
 
     List<String> argsList = [
-        SliderActions.ACTION_THAW, clustername,
+        SliderActions.ACTION_START, clustername,
         Arguments.ARG_MANAGER, RMAddr,
         Arguments.ARG_WAIT, WAIT_TIME_ARG,
         Arguments.ARG_FILESYSTEM, fsDefaultName,
@@ -710,7 +704,7 @@ public abstract class YarnMiniClusterTestBase extends 
ServiceLauncherBaseTest {
    * @return the exit code
    */
   public int clusterActionFreeze(SliderClient sliderClient, String clustername,
-                                 String message = "action freeze") {
+                                 String message = "action stop") {
     log.info("Freezing cluster $clustername: $message")
     ActionFreezeArgs freezeArgs  = new ActionFreezeArgs();
     freezeArgs.waittime = CLUSTER_STOP_TIME
@@ -718,7 +712,7 @@ public abstract class YarnMiniClusterTestBase extends 
ServiceLauncherBaseTest {
     int exitCode = sliderClient.actionFreeze(clustername,
         freezeArgs);
     if (exitCode != 0) {
-      log.warn("Cluster freeze failed with error code $exitCode")
+      log.warn("Cluster stop failed with error code $exitCode")
     }
     return exitCode
   }

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-core/src/test/resources/example-slider-test.xml
----------------------------------------------------------------------
diff --git a/slider-core/src/test/resources/example-slider-test.xml 
b/slider-core/src/test/resources/example-slider-test.xml
index a752cfd..cd11449 100644
--- a/slider-core/src/test/resources/example-slider-test.xml
+++ b/slider-core/src/test/resources/example-slider-test.xml
@@ -39,14 +39,14 @@
   </property>
 
   <property>
-    <name>slider.test.thaw.wait.seconds</name>
-    <description>Time to wait for a thaw to work</description>
+    <name>slider.test.start.wait.seconds</name>
+    <description>Time to wait for a start to work</description>
     <value>60</value>
   </property>
 
   <property>
-    <name>slider.test.freeze.wait.seconds</name>
-    <description>Time to wait for a freeze to work</description>
+    <name>slider.test.stop.wait.seconds</name>
+    <description>Time to wait for a stop to work</description>
     <value>60</value>
   </property>
 

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-funtest/src/main/groovy/org/apache/slider/funtest/framework/AgentCommandTestBase.groovy
----------------------------------------------------------------------
diff --git 
a/slider-funtest/src/main/groovy/org/apache/slider/funtest/framework/AgentCommandTestBase.groovy
 
b/slider-funtest/src/main/groovy/org/apache/slider/funtest/framework/AgentCommandTestBase.groovy
index 50f3ac0..6b7391a 100644
--- 
a/slider-funtest/src/main/groovy/org/apache/slider/funtest/framework/AgentCommandTestBase.groovy
+++ 
b/slider-funtest/src/main/groovy/org/apache/slider/funtest/framework/AgentCommandTestBase.groovy
@@ -178,7 +178,7 @@ implements FuntestProperties, Arguments, SliderExitCodes, 
SliderActions {
     log.info "Cleaning app instance, if exists, by name " + applicationName
     teardown(applicationName)
 
-    // sleep till the instance is frozen
+    // sleep till the instance is stopped
     sleep(1000 * 3)
 
     SliderShell shell = slider([

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-funtest/src/main/groovy/org/apache/slider/funtest/framework/CommandTestBase.groovy
----------------------------------------------------------------------
diff --git 
a/slider-funtest/src/main/groovy/org/apache/slider/funtest/framework/CommandTestBase.groovy
 
b/slider-funtest/src/main/groovy/org/apache/slider/funtest/framework/CommandTestBase.groovy
index 278bd2b..f65bd56 100644
--- 
a/slider-funtest/src/main/groovy/org/apache/slider/funtest/framework/CommandTestBase.groovy
+++ 
b/slider-funtest/src/main/groovy/org/apache/slider/funtest/framework/CommandTestBase.groovy
@@ -61,8 +61,8 @@ abstract class CommandTestBase extends SliderTestUtils {
   public static final File SLIDER_CONF_XML = new File(SLIDER_CONF_DIRECTORY,
       CLIENT_CONFIG_FILENAME).canonicalFile
   public static final YarnConfiguration SLIDER_CONFIG
-  public static final int THAW_WAIT_TIME
-  public static final int FREEZE_WAIT_TIME
+  public static final int START_WAIT_TIME
+  public static final int STOP_WAIT_TIME
 
   public static final int SLIDER_TEST_TIMEOUT
 
@@ -72,12 +72,12 @@ abstract class CommandTestBase extends SliderTestUtils {
 
   static {
     SLIDER_CONFIG = ConfLoader.loadSliderConf(SLIDER_CONF_XML);
-    THAW_WAIT_TIME = getTimeOptionMillis(SLIDER_CONFIG,
-        KEY_TEST_THAW_WAIT_TIME,
-        1000 * DEFAULT_THAW_WAIT_TIME_SECONDS)
-    FREEZE_WAIT_TIME = getTimeOptionMillis(SLIDER_CONFIG,
-        KEY_TEST_FREEZE_WAIT_TIME,
-        1000 * DEFAULT_TEST_FREEZE_WAIT_TIME_SECONDS)
+    START_WAIT_TIME = getTimeOptionMillis(SLIDER_CONFIG,
+        KEY_TEST_START_WAIT_TIME,
+        1000 * DEFAULT_START_WAIT_TIME_SECONDS)
+    STOP_WAIT_TIME = getTimeOptionMillis(SLIDER_CONFIG,
+        KEY_TEST_STOP_WAIT_TIME,
+        1000 * DEFAULT_TEST_STOP_WAIT_TIME_SECONDS)
     SLIDER_TEST_TIMEOUT = getTimeOptionMillis(SLIDER_CONFIG,
         KEY_TEST_TIMEOUT,
         1000 * DEFAULT_TEST_TIMEOUT_SECONDS)
@@ -205,32 +205,32 @@ abstract class CommandTestBase extends SliderTestUtils {
     slider(result, args)
   }
 
-  static SliderShell freeze(String name) {
+  static SliderShell stop(String name) {
     slider([
-        ACTION_FREEZE, name
+        ACTION_STOP, name
     ])
   }
 
 
-  static SliderShell freeze(
+  static SliderShell stop(
       int exitCode,
       String name,
       Collection<String> args) {
-    slider(exitCode, [ACTION_FREEZE, name] + args)
+    slider(exitCode, [ACTION_STOP, name] + args)
   }
 
   /**
-   * Freeze cluster: no exit code checking
+   * Stop cluster: no exit code checking
    * @param name
    * @param args
    * @return
    */
-  static SliderShell freeze(String name, Collection<String> args) {
-    slider([ACTION_FREEZE, name] + args)
+  static SliderShell stop(String name, Collection<String> args) {
+    slider([ACTION_STOP, name] + args)
   }
 
   static SliderShell freezeForce(String name) {
-    freeze(name, [ARG_FORCE])
+    stop(name, [ARG_FORCE])
   }
 
   static SliderShell getConf(String name) {
@@ -288,21 +288,21 @@ abstract class CommandTestBase extends SliderTestUtils {
         ])
   }
 
-  static SliderShell thaw(String name) {
+  static SliderShell start(String name) {
     slider([
-        ACTION_THAW, name
+        ACTION_START, name
     ])
   }
 
-  static SliderShell thaw(int result, String name) {
+  static SliderShell start(int result, String name) {
     slider(result,
         [
-            ACTION_THAW, name
+            ACTION_START, name
         ])
   }
 
-  static SliderShell thaw(String name, Collection<String> args) {
-    slider(0, [ACTION_THAW, name] + args)
+  static SliderShell start(String name, Collection<String> args) {
+    slider(0, [ACTION_START, name] + args)
   }
 
   static SliderShell registry(int result, Collection<String> commands) {
@@ -427,7 +427,7 @@ abstract class CommandTestBase extends SliderTestUtils {
 
 
     if (blockUntilRunning) {
-      argsList << ARG_WAIT << Integer.toString(THAW_WAIT_TIME)
+      argsList << ARG_WAIT << Integer.toString(START_WAIT_TIME)
     }
 
     List<String> roleList = [];

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-funtest/src/test/groovy/org/apache/slider/funtest/commands/UnknownClusterOperationsIT.groovy
----------------------------------------------------------------------
diff --git 
a/slider-funtest/src/test/groovy/org/apache/slider/funtest/commands/UnknownClusterOperationsIT.groovy
 
b/slider-funtest/src/test/groovy/org/apache/slider/funtest/commands/UnknownClusterOperationsIT.groovy
index 39ae4dd..081ff8c 100644
--- 
a/slider-funtest/src/test/groovy/org/apache/slider/funtest/commands/UnknownClusterOperationsIT.groovy
+++ 
b/slider-funtest/src/test/groovy/org/apache/slider/funtest/commands/UnknownClusterOperationsIT.groovy
@@ -26,7 +26,6 @@ import org.apache.slider.common.params.Arguments
 import org.apache.slider.common.params.SliderActions
 import org.apache.slider.funtest.framework.CommandTestBase
 import org.apache.slider.funtest.framework.SliderShell
-import org.junit.BeforeClass
 import org.junit.Test
 
 /**
@@ -41,7 +40,7 @@ public class UnknownClusterOperationsIT extends 
CommandTestBase {
 
   @Test
   public void testFreezeUnknownCluster() throws Throwable {
-    SliderShell shell = freeze(UNKNOWN)
+    SliderShell shell = stop(UNKNOWN)
     assertUnknownCluster(shell)
   }
 
@@ -49,8 +48,8 @@ public class UnknownClusterOperationsIT extends 
CommandTestBase {
   public void testFreezeUnknownClusterWithMessage() throws Throwable {
       slider(SliderExitCodes.EXIT_UNKNOWN_INSTANCE,
          [
-        SliderActions.ACTION_FREEZE, UNKNOWN,
-        Arguments.ARG_WAIT, Integer.toString(FREEZE_WAIT_TIME),
+        SliderActions.ACTION_STOP, UNKNOWN,
+        Arguments.ARG_WAIT, Integer.toString(STOP_WAIT_TIME),
         Arguments.ARG_MESSAGE, "testFreezeUnknownClusterWithMessage"
         ])
   }
@@ -84,7 +83,7 @@ public class UnknownClusterOperationsIT extends 
CommandTestBase {
 
   @Test
   public void testThawUnknownCluster() throws Throwable {
-    assertUnknownCluster(thaw(UNKNOWN))
+    assertUnknownCluster(start(UNKNOWN))
   }
 
   @Test

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-funtest/src/test/groovy/org/apache/slider/funtest/lifecycle/AgentClusterLifecycleIT.groovy
----------------------------------------------------------------------
diff --git 
a/slider-funtest/src/test/groovy/org/apache/slider/funtest/lifecycle/AgentClusterLifecycleIT.groovy
 
b/slider-funtest/src/test/groovy/org/apache/slider/funtest/lifecycle/AgentClusterLifecycleIT.groovy
index 6b0f2bd..f95548a 100644
--- 
a/slider-funtest/src/test/groovy/org/apache/slider/funtest/lifecycle/AgentClusterLifecycleIT.groovy
+++ 
b/slider-funtest/src/test/groovy/org/apache/slider/funtest/lifecycle/AgentClusterLifecycleIT.groovy
@@ -88,8 +88,8 @@ public class AgentClusterLifecycleIT extends 
AgentCommandTestBase
     //destroy will fail in use
     destroy(EXIT_APPLICATION_IN_USE, CLUSTER)
 
-    //thaw will fail as cluster is in use
-    thaw(EXIT_APPLICATION_IN_USE, CLUSTER)
+    //start will fail as cluster is in use
+    start(EXIT_APPLICATION_IN_USE, CLUSTER)
 
     //it's still there
     exists(0, CLUSTER)
@@ -125,34 +125,34 @@ public class AgentClusterLifecycleIT extends 
AgentCommandTestBase
 
       log.info("Connected via Client {}", sliderClient.toString())
 
-      //freeze
-      freeze(0, CLUSTER, [
-          ARG_WAIT, Integer.toString(FREEZE_WAIT_TIME),
-          ARG_MESSAGE, "freeze-in-test-cluster-lifecycle"
+      //stop
+      stop(0, CLUSTER, [
+          ARG_WAIT, Integer.toString(STOP_WAIT_TIME),
+          ARG_MESSAGE, "stop-in-test-cluster-lifecycle"
       ])
-      describe " >>> Cluster is now frozen."
+      describe " >>> Cluster is now stopped."
 
       //cluster exists if you don't want it to be live
       exists(0, CLUSTER, false)
       //condition returns false if it is required to be live
       exists(EXIT_FALSE, CLUSTER, true)
 
-      //thaw then freeze the cluster
-      thaw(CLUSTER,
+      //start then stop the cluster
+      start(CLUSTER,
           [
-              ARG_WAIT, Integer.toString(THAW_WAIT_TIME),
+              ARG_WAIT, Integer.toString(START_WAIT_TIME),
           ])
       exists(0, CLUSTER)
-      describe " >>> Cluster is now thawed."
+      describe " >>> Cluster is now started."
 
-      freeze(0, CLUSTER,
+      stop(0, CLUSTER,
           [
               ARG_FORCE,
-              ARG_WAIT, Integer.toString(FREEZE_WAIT_TIME),
-              ARG_MESSAGE, "forced-freeze-in-test"
+              ARG_WAIT, Integer.toString(STOP_WAIT_TIME),
+              ARG_MESSAGE, "forced-stop-in-test"
           ])
 
-      describe " >>> Cluster is now frozen - 2nd time."
+      describe " >>> Cluster is now stopped - 2nd time."
 
       //cluster is no longer live
       exists(0, CLUSTER, false)
@@ -160,15 +160,15 @@ public class AgentClusterLifecycleIT extends 
AgentCommandTestBase
       //condition returns false if it is required to be live
       exists(EXIT_FALSE, CLUSTER, true)
 
-      //thaw with a restart count set to enable restart
+      //start with a restart count set to enable restart
       describe "the kill/restart phase may fail if 
yarn.resourcemanager.am.max-attempts is too low"
-      thaw(CLUSTER,
+      start(CLUSTER,
           [
-              ARG_WAIT, Integer.toString(THAW_WAIT_TIME),
+              ARG_WAIT, Integer.toString(START_WAIT_TIME),
               ARG_DEFINE, SliderXmlConfKeys.KEY_AM_RESTART_LIMIT + "=3"
           ])
 
-      describe " >>> Cluster is now thawed - 2nd time."
+      describe " >>> Cluster is now started - 2nd time."
 
       ClusterDescription status = killAmAndWaitForRestart(sliderClient, 
CLUSTER)
 
@@ -178,10 +178,10 @@ public class AgentClusterLifecycleIT extends 
AgentCommandTestBase
           StatusKeys.INFO_CONTAINERS_AM_RESTART)
       assert restarted != null
       assert Integer.parseInt(restarted) == 0
-      freeze(0, CLUSTER,
+      stop(0, CLUSTER,
           [
               ARG_FORCE,
-              ARG_WAIT, Integer.toString(FREEZE_WAIT_TIME),
+              ARG_WAIT, Integer.toString(STOP_WAIT_TIME),
               ARG_MESSAGE, "final-shutdown"
           ])
 

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-funtest/src/test/manual/python/SliderTester.py
----------------------------------------------------------------------
diff --git a/slider-funtest/src/test/manual/python/SliderTester.py 
b/slider-funtest/src/test/manual/python/SliderTester.py
index 40bdf2b..f7fc564 100644
--- a/slider-funtest/src/test/manual/python/SliderTester.py
+++ b/slider-funtest/src/test/manual/python/SliderTester.py
@@ -235,7 +235,7 @@ class SliderTester:
     pass
 
   def clean_up(self):
-    (retcode, out, err) = self.run_slider_command(" ".join([self.slider_exec, 
"freeze", self.cluster_name]),
+    (retcode, out, err) = self.run_slider_command(" ".join([self.slider_exec, 
"stop", self.cluster_name]),
                                                   self.slider_user)
     if retcode != 0:
       raise Exception("Could not clean cluster. Out: " + out + " Err: " + err)
@@ -352,7 +352,7 @@ def main():
   # Finalize resources and appConf json files
   # Call create
   # Validate existence of the app
-  # Call freeze
+  # Call stop
 
 
 if __name__ == "__main__":

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-providers/accumulo/accumulo-funtests/src/test/groovy/org/apache/slider/providers/accumulo/funtest/FunctionalAccumuloM1T1GC1Mon1IT.groovy
----------------------------------------------------------------------
diff --git 
a/slider-providers/accumulo/accumulo-funtests/src/test/groovy/org/apache/slider/providers/accumulo/funtest/FunctionalAccumuloM1T1GC1Mon1IT.groovy
 
b/slider-providers/accumulo/accumulo-funtests/src/test/groovy/org/apache/slider/providers/accumulo/funtest/FunctionalAccumuloM1T1GC1Mon1IT.groovy
index 33910d4..7a7b84e 100644
--- 
a/slider-providers/accumulo/accumulo-funtests/src/test/groovy/org/apache/slider/providers/accumulo/funtest/FunctionalAccumuloM1T1GC1Mon1IT.groovy
+++ 
b/slider-providers/accumulo/accumulo-funtests/src/test/groovy/org/apache/slider/providers/accumulo/funtest/FunctionalAccumuloM1T1GC1Mon1IT.groovy
@@ -43,12 +43,12 @@ public class FunctionalAccumuloM1T1GC1Mon1IT extends 
FunctionalAccumuloClusterIT
       ClusterDescription cd) {
 
     slider(0, [
-      SliderActions.ACTION_FREEZE,
+      SliderActions.ACTION_STOP,
       getClusterName(),
       Arguments.ARG_WAIT,
-      Integer.toString(FREEZE_WAIT_TIME),
+      Integer.toString(STOP_WAIT_TIME),
       Arguments.ARG_MESSAGE,
-      "freeze-in-test-AccumuloCluster"
+      "stop-in-test-AccumuloCluster"
     ])
     
     //destroy the cluster. This only works if the permissions allow it

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-providers/accumulo/slider-accumulo-provider/src/test/groovy/org/apache/slider/providers/accumulo/live/TestAccFreezeThaw.groovy
----------------------------------------------------------------------
diff --git 
a/slider-providers/accumulo/slider-accumulo-provider/src/test/groovy/org/apache/slider/providers/accumulo/live/TestAccFreezeThaw.groovy
 
b/slider-providers/accumulo/slider-accumulo-provider/src/test/groovy/org/apache/slider/providers/accumulo/live/TestAccFreezeThaw.groovy
index 6da00fb..29d25a5 100644
--- 
a/slider-providers/accumulo/slider-accumulo-provider/src/test/groovy/org/apache/slider/providers/accumulo/live/TestAccFreezeThaw.groovy
+++ 
b/slider-providers/accumulo/slider-accumulo-provider/src/test/groovy/org/apache/slider/providers/accumulo/live/TestAccFreezeThaw.groovy
@@ -69,7 +69,7 @@ class TestAccFreezeThaw extends AccumuloTestBase {
     log.info(page);
 
     log.info("Freezing")
-    clusterActionFreeze(sliderClient, clustername, "freeze");
+    clusterActionFreeze(sliderClient, clustername, "stop");
     waitForAppToFinish(sliderClient)
     
     //make sure the fetch fails

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-providers/hbase/hbase-funtests/src/test/groovy/org/apache/slider/providers/hbase/funtest/HBaseClusterLifecycleIT.groovy
----------------------------------------------------------------------
diff --git 
a/slider-providers/hbase/hbase-funtests/src/test/groovy/org/apache/slider/providers/hbase/funtest/HBaseClusterLifecycleIT.groovy
 
b/slider-providers/hbase/hbase-funtests/src/test/groovy/org/apache/slider/providers/hbase/funtest/HBaseClusterLifecycleIT.groovy
index 63b5fb6..b09e95b 100644
--- 
a/slider-providers/hbase/hbase-funtests/src/test/groovy/org/apache/slider/providers/hbase/funtest/HBaseClusterLifecycleIT.groovy
+++ 
b/slider-providers/hbase/hbase-funtests/src/test/groovy/org/apache/slider/providers/hbase/funtest/HBaseClusterLifecycleIT.groovy
@@ -80,8 +80,8 @@ public class HBaseClusterLifecycleIT extends 
HBaseCommandTestBase
 
     destroy(EXIT_APPLICATION_IN_USE, CLUSTER)
 
-    //thaw will fail as cluster is in use
-    thaw(EXIT_APPLICATION_IN_USE, CLUSTER)
+    //start will fail as cluster is in use
+    start(EXIT_APPLICATION_IN_USE, CLUSTER)
 
     //it's still there
     exists(0, CLUSTER)
@@ -117,12 +117,12 @@ public class HBaseClusterLifecycleIT extends 
HBaseCommandTestBase
 
       log.info("Connected via Client {}", sliderClient.toString())
 
-      //freeze
-      def frozen = freeze(0, CLUSTER, [
-          ARG_WAIT, Integer.toString(FREEZE_WAIT_TIME),
-          ARG_MESSAGE, "freeze-in-test-cluster-lifecycle"
+      //stop
+      def stopped = stop(0, CLUSTER, [
+          ARG_WAIT, Integer.toString(STOP_WAIT_TIME),
+          ARG_MESSAGE, "stop-in-test-cluster-lifecycle"
       ])
-      frozen.assertExitCode(0)
+      stopped.assertExitCode(0)
 
 //      sleep(FREEZE_WAIT_TIME)
       //cluster exists if you don't want it to be live
@@ -131,18 +131,18 @@ public class HBaseClusterLifecycleIT extends 
HBaseCommandTestBase
       exists(EXIT_FALSE, CLUSTER, true)
 
 
-      // thaw then freeze the cluster
+      // start then stop the cluster
 
-      thaw(CLUSTER,
+      start(CLUSTER,
           [
-              ARG_WAIT, Integer.toString(THAW_WAIT_TIME),
+              ARG_WAIT, Integer.toString(START_WAIT_TIME),
           ])
       exists(0, CLUSTER)
-      freeze(0, CLUSTER,
+      stop(0, CLUSTER,
           [
               ARG_FORCE,
-              ARG_WAIT, Integer.toString(FREEZE_WAIT_TIME),
-              ARG_MESSAGE, "forced-freeze-in-test"
+              ARG_WAIT, Integer.toString(STOP_WAIT_TIME),
+              ARG_MESSAGE, "forced-stop-in-test"
           ])
 
       //cluster is no longer live
@@ -151,12 +151,12 @@ public class HBaseClusterLifecycleIT extends 
HBaseCommandTestBase
       // condition returns false if it is required to be live
       exists(EXIT_FALSE, CLUSTER, true)
 
-      // thaw with a restart count set to enable restart
+      // start with a restart count set to enable restart
 
       describe "the kill/restart phase may fail if 
yarn.resourcemanager.am.max-attempts is too low"
-      thaw(CLUSTER,
+      start(CLUSTER,
           [
-              ARG_WAIT, Integer.toString(THAW_WAIT_TIME),
+              ARG_WAIT, Integer.toString(START_WAIT_TIME),
               ARG_DEFINE, SliderXmlConfKeys.KEY_AM_RESTART_LIMIT + "=3"
           ])
 
@@ -167,11 +167,11 @@ public class HBaseClusterLifecycleIT extends 
HBaseCommandTestBase
           StatusKeys.INFO_CONTAINERS_AM_RESTART)
       assert restarted != null
       assert Integer.parseInt(restarted) == 0
-      freeze(0, CLUSTER,
+      stop(0, CLUSTER,
           [
               ARG_FORCE,
-              ARG_WAIT, Integer.toString(FREEZE_WAIT_TIME),
-              ARG_MESSAGE, "teardown-freeze"
+              ARG_WAIT, Integer.toString(STOP_WAIT_TIME),
+              ARG_MESSAGE, "teardown-stop"
           ])
       
 

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-providers/hbase/slider-hbase-provider/src/test/groovy/org/apache/slider/providers/hbase/minicluster/archives/TestFreezeThawClusterFromArchive.groovy
----------------------------------------------------------------------
diff --git 
a/slider-providers/hbase/slider-hbase-provider/src/test/groovy/org/apache/slider/providers/hbase/minicluster/archives/TestFreezeThawClusterFromArchive.groovy
 
b/slider-providers/hbase/slider-hbase-provider/src/test/groovy/org/apache/slider/providers/hbase/minicluster/archives/TestFreezeThawClusterFromArchive.groovy
index 85726a7..09a87a9 100644
--- 
a/slider-providers/hbase/slider-hbase-provider/src/test/groovy/org/apache/slider/providers/hbase/minicluster/archives/TestFreezeThawClusterFromArchive.groovy
+++ 
b/slider-providers/hbase/slider-hbase-provider/src/test/groovy/org/apache/slider/providers/hbase/minicluster/archives/TestFreezeThawClusterFromArchive.groovy
@@ -51,7 +51,7 @@ class TestFreezeThawClusterFromArchive extends 
HBaseMiniClusterTestBase {
                             hbaseClusterStartupToLiveTime)
 
 
-    clusterActionFreeze(sliderClient, clustername, "test freeze")
+    clusterActionFreeze(sliderClient, clustername, "test stop")
     describe("Restarting cluster")
     killAllRegionServers();
 

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-providers/hbase/slider-hbase-provider/src/test/groovy/org/apache/slider/providers/hbase/minicluster/build/TestBuildThawClusterM1W1.groovy
----------------------------------------------------------------------
diff --git 
a/slider-providers/hbase/slider-hbase-provider/src/test/groovy/org/apache/slider/providers/hbase/minicluster/build/TestBuildThawClusterM1W1.groovy
 
b/slider-providers/hbase/slider-hbase-provider/src/test/groovy/org/apache/slider/providers/hbase/minicluster/build/TestBuildThawClusterM1W1.groovy
index c305b5b..9328f16 100644
--- 
a/slider-providers/hbase/slider-hbase-provider/src/test/groovy/org/apache/slider/providers/hbase/minicluster/build/TestBuildThawClusterM1W1.groovy
+++ 
b/slider-providers/hbase/slider-hbase-provider/src/test/groovy/org/apache/slider/providers/hbase/minicluster/build/TestBuildThawClusterM1W1.groovy
@@ -40,7 +40,7 @@ class TestBuildThawClusterM1W1 extends 
HBaseMiniClusterTestBase {
   public void test_build_thaw_cluster_m1_w1() throws Throwable {
     String clustername = createMiniCluster("", configuration, 1, true)
 
-    describe "verify that a built cluster can be thawed"
+    describe "verify that a built cluster can be started"
 
     ServiceLauncher<SliderClient> launcher = createOrBuildCluster(
         SliderActions.ACTION_BUILD,
@@ -61,11 +61,11 @@ class TestBuildThawClusterM1W1 extends 
HBaseMiniClusterTestBase {
     ApplicationReport report = serviceRegistryClient.findInstance(clustername)
     assert report == null;
 
-    //thaw time
+    //start time
     ServiceLauncher<SliderClient> l2 = thawCluster(clustername, [], true)
-    SliderClient thawed = l2.service
-    addToTeardown(thawed);
-    waitForClusterLive(thawed)
+    SliderClient started = l2.service
+    addToTeardown(started);
+    waitForClusterLive(started)
   }
 
 }

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-providers/hbase/slider-hbase-provider/src/test/groovy/org/apache/slider/providers/hbase/minicluster/freezethaw/TestFreezeReconfigureThawLiveRegionService.groovy
----------------------------------------------------------------------
diff --git 
a/slider-providers/hbase/slider-hbase-provider/src/test/groovy/org/apache/slider/providers/hbase/minicluster/freezethaw/TestFreezeReconfigureThawLiveRegionService.groovy
 
b/slider-providers/hbase/slider-hbase-provider/src/test/groovy/org/apache/slider/providers/hbase/minicluster/freezethaw/TestFreezeReconfigureThawLiveRegionService.groovy
index f6748e0..19e162c 100644
--- 
a/slider-providers/hbase/slider-hbase-provider/src/test/groovy/org/apache/slider/providers/hbase/minicluster/freezethaw/TestFreezeReconfigureThawLiveRegionService.groovy
+++ 
b/slider-providers/hbase/slider-hbase-provider/src/test/groovy/org/apache/slider/providers/hbase/minicluster/freezethaw/TestFreezeReconfigureThawLiveRegionService.groovy
@@ -54,8 +54,8 @@ class TestFreezeReconfigureThawLiveRegionService
     conf.setInt("yarn.nodemanager.resource.cpu-vcores", 1)
     String clustername = createMiniCluster("", conf, nodemanagers, true)
     describe(
-        "Create a $regionServerCount node cluster, freeze it, patch the 
configuration files," +
-        " thaw it and verify that it came back with the new settings")
+        "Create a $regionServerCount node cluster, stop it, patch the 
configuration files," +
+        " start it and verify that it came back with the new settings")
 
     ServiceLauncher<SliderClient> launcher = createHBaseCluster(
         clustername,
@@ -103,18 +103,18 @@ class TestFreezeReconfigureThawLiveRegionService
         hbaseSiteXML,
         "");
     //patch
-    String patchedText = "patched-after-freeze"
+    String patchedText = "patched-after-stop"
     originalConf.setBoolean(patchedText, true);
     //save
     ConfigHelper.saveConfig(dfs, hbaseSiteXML, originalConf);
 
     //now let's start the cluster up again
     ServiceLauncher<SliderClient> launcher2 = thawCluster(clustername, [], 
true);
-    SliderClient thawed = launcher2.service
-    clustat = basicHBaseClusterStartupSequence(thawed)
+    SliderClient started = launcher2.service
+    clustat = basicHBaseClusterStartupSequence(started)
 
     //get the options
-    ClusterDescription stat = thawed.clusterDescription
+    ClusterDescription stat = started.clusterDescription
     Map<String, String> properties = stat.clientProperties
     log.info("Cluster properties: \n" + SliderUtils.stringifyMap(properties));
     assert properties[patchedText] == "true";

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-providers/hbase/slider-hbase-provider/src/test/groovy/org/apache/slider/providers/hbase/minicluster/freezethaw/TestFreezeThawLiveRegionService.groovy
----------------------------------------------------------------------
diff --git 
a/slider-providers/hbase/slider-hbase-provider/src/test/groovy/org/apache/slider/providers/hbase/minicluster/freezethaw/TestFreezeThawLiveRegionService.groovy
 
b/slider-providers/hbase/slider-hbase-provider/src/test/groovy/org/apache/slider/providers/hbase/minicluster/freezethaw/TestFreezeThawLiveRegionService.groovy
index 66dd4f0..b6861db 100644
--- 
a/slider-providers/hbase/slider-hbase-provider/src/test/groovy/org/apache/slider/providers/hbase/minicluster/freezethaw/TestFreezeThawLiveRegionService.groovy
+++ 
b/slider-providers/hbase/slider-hbase-provider/src/test/groovy/org/apache/slider/providers/hbase/minicluster/freezethaw/TestFreezeThawLiveRegionService.groovy
@@ -43,7 +43,7 @@ class TestFreezeThawLiveRegionService extends 
HBaseMiniClusterTestBase {
   public void testFreezeThawLiveRegionService() throws Throwable {
     int regionServerCount = 2
     String clustername = createMiniCluster("", configuration, 1, true)
-    describe("Create a cluster, freeze it, thaw it and verify that it came 
back ")
+    describe("Create a cluster, stop it, start it and verify that it came back 
")
     //use a smaller AM HEAP to include it in the test cycle
     ServiceLauncher launcher = createHBaseCluster(clustername, 
regionServerCount,
         [
@@ -84,7 +84,7 @@ class TestFreezeThawLiveRegionService extends 
HBaseMiniClusterTestBase {
     waitForHBaseRegionServerCount(newCluster, clustername, regionServerCount,
                             hbaseClusterStartupToLiveTime)
     
-    // finally, attempt to thaw it while it is running
+    // finally, attempt to start it while it is running
     //now let's start the cluster up again
     try {
       ServiceLauncher launcher3 = thawCluster(clustername, [], true);

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-providers/hbase/slider-hbase-provider/src/test/groovy/org/apache/slider/providers/hbase/minicluster/live/TestTwoLiveClusters.groovy
----------------------------------------------------------------------
diff --git 
a/slider-providers/hbase/slider-hbase-provider/src/test/groovy/org/apache/slider/providers/hbase/minicluster/live/TestTwoLiveClusters.groovy
 
b/slider-providers/hbase/slider-hbase-provider/src/test/groovy/org/apache/slider/providers/hbase/minicluster/live/TestTwoLiveClusters.groovy
index 7e4c5ed..e5f4bef 100644
--- 
a/slider-providers/hbase/slider-hbase-provider/src/test/groovy/org/apache/slider/providers/hbase/minicluster/live/TestTwoLiveClusters.groovy
+++ 
b/slider-providers/hbase/slider-hbase-provider/src/test/groovy/org/apache/slider/providers/hbase/minicluster/live/TestTwoLiveClusters.groovy
@@ -109,8 +109,8 @@ class TestTwoLiveClusters extends HBaseMiniClusterTestBase {
         HBaseKeys.HBASE_SERVICE_TYPE, clustername2).payload
     assert !(hbase1ServiceData == hbase2ServiceData)
 
-    clusterActionFreeze(cluster2Client, clustername2,"freeze cluster 2")
-    clusterActionFreeze(sliderClient, clustername1,"Freeze cluster 1")
+    clusterActionFreeze(cluster2Client, clustername2,"stop cluster 2")
+    clusterActionFreeze(sliderClient, clustername1,"Stop cluster 1")
 
   }
 

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/src/test/clusters/sandbox/operations.md
----------------------------------------------------------------------
diff --git a/src/test/clusters/sandbox/operations.md 
b/src/test/clusters/sandbox/operations.md
index 0ff5a3a..932f6d5 100644
--- a/src/test/clusters/sandbox/operations.md
+++ b/src/test/clusters/sandbox/operations.md
@@ -118,10 +118,10 @@
      
      
                
-    bin/slider  thaw cl1  
+    bin/slider  start cl1
                    
-    bin/slider  freeze cl1  
-    bin/slider  freeze cluster3  
+    bin/slider  stop cl1
+    bin/slider  stop cluster3
     bin/slider  destroy cl1  
     
     
@@ -149,20 +149,20 @@
       --component master 1 \
       --component worker 2 
     
-### freeze
+### stop
 
-    bin/slider  freeze cl1 
+    bin/slider  stop cl1
     
-    bin/slider  freeze cl1 --force 
+    bin/slider  stop cl1 --force
     
-### thaw
+### start
 
-    bin/slider  thaw cl1 -D slider.yarn.queue.priority=5 -D 
slider.yarn.queue=default
+    bin/slider  start cl1 -D slider.yarn.queue.priority=5 -D 
slider.yarn.queue=default
     
     
-### thaw with bad queue: _MUST_ fail
+### start with bad queue: _MUST_ fail
     
-    bin/slider  thaw cl1 -D slider.yarn.queue=unknown
+    bin/slider  start cl1 -D slider.yarn.queue=unknown
      
 ### monitor
 

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/src/test/clusters/ubuntu-secure/operations.md
----------------------------------------------------------------------
diff --git a/src/test/clusters/ubuntu-secure/operations.md 
b/src/test/clusters/ubuntu-secure/operations.md
index d894038..1f92290 100644
--- a/src/test/clusters/ubuntu-secure/operations.md
+++ b/src/test/clusters/ubuntu-secure/operations.md
@@ -198,21 +198,21 @@
      
      
                
-    bin/slider  thaw cl1 \
+    bin/slider  start cl1 \
     --manager ubuntu:8032 --filesystem hdfs://ubuntu:9090 \
     \
      -S java.security.krb5.realm=COTHAM -S java.security.krb5.kdc=ubuntu \
      -D yarn.resourcemanager.principal=yarn/ubuntu@COTHAM \
      -D dfs.namenode.kerberos.principal=hdfs/ubuntu@COTHAM 
                    
-    bin/slider  freeze cl1 \
+    bin/slider  stop cl1 \
     --manager ubuntu:8032 --filesystem hdfs://ubuntu:9090 \
     \
     -S java.security.krb5.realm=COTHAM -S java.security.krb5.kdc=ubuntu \
      -D yarn.resourcemanager.principal=yarn/ubuntu@COTHAM \
      -D dfs.namenode.kerberos.principal=hdfs/ubuntu@COTHAM   
                       
-    bin/slider  freeze cluster3 \
+    bin/slider  stop cluster3 \
     --manager ubuntu:8032 --filesystem hdfs://ubuntu:9090 \
     \
     -S java.security.krb5.realm=COTHAM -S java.security.krb5.kdc=ubuntu \
@@ -259,13 +259,13 @@
       --role master 1 \
       --role worker 2 
     
-# freeze
+# stop
 
-    bin/slider  freeze cl1 
+    bin/slider  stop cl1
     
-# thaw
+# start
 
-    bin/slider  thaw cl1
+    bin/slider  start cl1
      
 # monitor
 

Reply via email to
diff --git 
a/slider-core/src/main/java/org/apache/slider/client/SliderClient.java 
b/slider-core/src/main/java/org/apache/slider/client/SliderClient.java
index 77cd244..e3520da 100644
--- a/slider-core/src/main/java/org/apache/slider/client/SliderClient.java
+++ b/slider-core/src/main/java/org/apache/slider/client/SliderClient.java
@@ -298,10 +298,10 @@ public class SliderClient extends 
AbstractSliderLaunchedService implements RunSe
       exitCode = actionBuild(clusterName, serviceArgs.getActionBuildArgs());
     } else if (ACTION_CREATE.equals(action)) {
       exitCode = actionCreate(clusterName, serviceArgs.getActionCreateArgs());
-    } else if (ACTION_FREEZE.equals(action)) {
+    } else if (ACTION_STOP.equals(action)) {
       exitCode = actionFreeze(clusterName,
-          serviceArgs.getActionFreezeArgs());
-    } else if (ACTION_THAW.equals(action)) {
+                            serviceArgs.getActionFreezeArgs());
+    } else if (ACTION_START.equals(action)) {
       exitCode = actionThaw(clusterName, serviceArgs.getActionThawArgs());
     } else if (ACTION_DESTROY.equals(action)) {
       exitCode = actionDestroy(clusterName);
@@ -1746,10 +1746,10 @@ public class SliderClient extends 
AbstractSliderLaunchedService implements RunSe
   }
 
   /**
    * Freeze the cluster
    *
    * @param clustername cluster name
    * @param freezeArgs arguments to the freeze
    * @return EXIT_SUCCESS if the cluster was not running by the end of the 
operation
    */
   public int actionFreeze(String clustername,
@@ -1772,10 +1772,10 @@ public class SliderClient extends 
AbstractSliderLaunchedService implements RunSe
     if (app == null) {
       // exit early
       log.info("Cluster {} not running", clustername);
       // not an error to freeze a frozen cluster
       return EXIT_SUCCESS;
     }
-    log.debug("App to freeze was found: {}:\n{}", clustername,
+    log.debug("App to stop was found: {}:\n{}", clustername,
               new SliderUtils.OnDemandReportStringifier(app));
     if (app.getYarnApplicationState().ordinal() >=
         YarnApplicationState.FINISHED.ordinal()) {
@@ -1789,7 +1789,7 @@ public class SliderClient extends 
AbstractSliderLaunchedService implements RunSe
 
     if (forcekill) {
       //escalating to forced kill
-      application.kill("Forced freeze of " + clustername +
+      application.kill("Forced stop of " + clustername +
                        ": " + text);
     } else {
       try {
@@ -1935,7 +1935,7 @@ public class SliderClient extends 
AbstractSliderLaunchedService implements RunSe
   /**
    * Restore a cluster
    */
-  public int actionThaw(String clustername, ActionThawArgs thaw) throws 
YarnException, IOException {
+  public int actionThaw(String clustername, ActionThawArgs start) throws 
YarnException, IOException {
     SliderUtils.validateClusterName(clustername);
     // see if it is actually running and bail out;
     verifyBindingsDefined();
@@ -1943,7 +1943,7 @@ public class SliderClient extends 
AbstractSliderLaunchedService implements RunSe
 
 
     //start the cluster
-    return startCluster(clustername, thaw);
+    return startCluster(clustername, start);
   }
 
   /**

http://git-wip-us.apache.org/repos/asf/incubator-slider/blob/be548b87/slider-core/src/main/java/org/apache/slider/common/SliderXMLConfKeysForTesting.java
----------------------------------------------------------------------
@@ -1746,10 +1746,10 @@ public class SliderClient extends 
 
   /**
-   * Freeze the cluster
+   * Stop the cluster
    *
    * @param clustername cluster name
@@ -1746,10 +1746,10 @@ public class SliderClient extends 
    *
    * @param clustername cluster name
-   * @param freezeArgs arguments to the freeze
+   * @param freezeArgs arguments to the stop
    * @return EXIT_SUCCESS if the cluster was not running by the end of the 
operation
@@ -1772,10 +1772,10 @@ public class SliderClient extends 
       // exit early
       log.info("Cluster {} not running", clustername);
-      // not an error to freeze a frozen cluster
+      // not an error to stop a stopped cluster
       return EXIT_SUCCESS;
     }